aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorKazu Hirata <kazu@cs.umass.edu>2004-03-25 17:04:45 +0000
committerKazu Hirata <kazu@cs.umass.edu>2004-03-25 17:04:45 +0000
commite2e641971be2268fad5aaa09d288c1167b4aa781 (patch)
treea07fa2ef52cb57e6407820f14274be6122b01dbe
parentb1ef14320cdf25b3292da37526524fddeaddd3b5 (diff)
gcc/
* cfgrtl.c, dbxout.c, tree.def, config/darwin.h, config/arm/arm.c, objc/objc-act.c: Fix comment typos. * doc/invoke.texi: Fix a typo. cp/ * cxx-pretty-print.c: Fix comment typos. git-svn-id: https://gcc.gnu.org/svn/gcc/trunk@79956 138bc75d-0d04-0410-961f-82ee72b054a4
-rw-r--r--gcc/ChangeLog6
-rw-r--r--gcc/cfgrtl.c2
-rw-r--r--gcc/config/arm/arm.c8
-rw-r--r--gcc/config/darwin.h2
-rw-r--r--gcc/cp/ChangeLog4
-rw-r--r--gcc/cp/cxx-pretty-print.c4
-rw-r--r--gcc/dbxout.c4
-rw-r--r--gcc/doc/invoke.texi2
-rw-r--r--gcc/objc/objc-act.c6
-rw-r--r--gcc/tree.def2
10 files changed, 25 insertions, 15 deletions
diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index e63bbffaf12..f3be4d5c3fb 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,5 +1,11 @@
2004-03-25 Kazu Hirata <kazu@cs.umass.edu>
+ * cfgrtl.c, dbxout.c, tree.def, config/darwin.h,
+ config/arm/arm.c, objc/objc-act.c: Fix comment typos.
+ * doc/invoke.texi: Fix a typo.
+
+2004-03-25 Kazu Hirata <kazu@cs.umass.edu>
+
PR optimization/9707.
* stmt.c (emit_case_nodes): Emit equality comparisons instead
of recursing if both children are single-valued cases with no
diff --git a/gcc/cfgrtl.c b/gcc/cfgrtl.c
index 20de6259fab..c292c7ad974 100644
--- a/gcc/cfgrtl.c
+++ b/gcc/cfgrtl.c
@@ -2105,7 +2105,7 @@ rtl_verify_flow_info (void)
break;
case CODE_LABEL:
- /* An addr_vec is placed outside any block block. */
+ /* An addr_vec is placed outside any basic block. */
if (NEXT_INSN (x)
&& GET_CODE (NEXT_INSN (x)) == JUMP_INSN
&& (GET_CODE (PATTERN (NEXT_INSN (x))) == ADDR_DIFF_VEC
diff --git a/gcc/config/darwin.h b/gcc/config/darwin.h
index 8a659d9ed8f..2e7ee243963 100644
--- a/gcc/config/darwin.h
+++ b/gcc/config/darwin.h
@@ -341,7 +341,7 @@ do { text_section (); \
#undef USE_COMMON_FOR_ONE_ONLY
#define USE_COMMON_FOR_ONE_ONLY 0
-/* The Darwin linker doesn't like explicit template instantions to be
+/* The Darwin linker doesn't like explicit template instantiations to be
coalesced, because it doesn't want coalesced symbols to appear in
a static archive's table of contents. */
#undef TARGET_EXPLICIT_INSTANTIATIONS_ONE_ONLY
diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
index 7c5c6f7a76c..e59e9c1a9ec 100644
--- a/gcc/cp/ChangeLog
+++ b/gcc/cp/ChangeLog
@@ -1,3 +1,7 @@
+2004-03-25 Kazu Hirata <kazu@cs.umass.edu>
+
+ * cxx-pretty-print.c: Fix comment typos.
+
2004-03-24 Kazu Hirata <kazu@cs.umass.edu>
* cxx-pretty-print.c, cxx-pretty-print.h, decl.h, friend.c:
diff --git a/gcc/cp/cxx-pretty-print.c b/gcc/cp/cxx-pretty-print.c
index 88a800dd39b..a07f0090871 100644
--- a/gcc/cp/cxx-pretty-print.c
+++ b/gcc/cp/cxx-pretty-print.c
@@ -198,7 +198,7 @@ pp_cxx_unqualified_id (cxx_pretty_printer *pp, tree t)
/* Pretty-print out the token sequence ":: template" in template codes
where it is needed to "inline declare" the (following) member as
- a template. This situtation arises when SCOPE of T is dependent
+ a template. This situation arises when SCOPE of T is dependent
on template parameters. */
static inline void
@@ -242,7 +242,7 @@ pp_cxx_qualified_id (cxx_pretty_printer *pp, tree t)
/* In Standard C++, functions cannot possibly be used as
nested-name-specifiers. However, there are situations where
- is "makes sense" to output the surrouding function name for the
+ is "makes sense" to output the surrounding function name for the
purpose of emphasizing on the scope kind. Just printing the
function name might not be sufficient as it may be overloaded; so,
we decorate the function with its signature too.
diff --git a/gcc/dbxout.c b/gcc/dbxout.c
index 89ba1cf6a86..99d2767d962 100644
--- a/gcc/dbxout.c
+++ b/gcc/dbxout.c
@@ -884,8 +884,8 @@ dbxout_type_fields (tree type)
field that we can support. */
for (tem = TYPE_FIELDS (type); tem; tem = TREE_CHAIN (tem))
{
-
- /* If on of the nodes is an error_mark or its type is then return early. */
+ /* If one of the nodes is an error_mark or its type is then
+ return early. */
if (tem == error_mark_node || TREE_TYPE (tem) == error_mark_node)
return;
diff --git a/gcc/doc/invoke.texi b/gcc/doc/invoke.texi
index dcd72eb1772..d9ef797bc5e 100644
--- a/gcc/doc/invoke.texi
+++ b/gcc/doc/invoke.texi
@@ -6653,7 +6653,7 @@ if the underlying ABI supports it.
Specifying the larger number can produce faster, more efficient code, but
can also increase the size of the program. Different values are potentially
incompatible. Code compiled with one value cannot necessarily expect to
-work with code or libraries compiled with annother value, if they exchange
+work with code or libraries compiled with another value, if they exchange
information using structures or unions.
@item -mabort-on-noreturn
diff --git a/gcc/objc/objc-act.c b/gcc/objc/objc-act.c
index 22696cb519e..ae0a98e5371 100644
--- a/gcc/objc/objc-act.c
+++ b/gcc/objc/objc-act.c
@@ -3304,7 +3304,7 @@ build_objc_exception_stuff (void)
finish_struct (objc_exception_data_template, field_decl_chain, NULL_TREE);
/* int _setjmp(...); */
- /* If the user includes <setjmp.h>, this shall be superceded by
+ /* If the user includes <setjmp.h>, this shall be superseded by
'int _setjmp(jmp_buf);' */
temp_type = build_function_type (integer_type_node, NULL_TREE);
objc_setjmp_decl
@@ -5536,7 +5536,7 @@ receiver_is_class_object (tree receiver, int self, int super)
&& (exp = TREE_OPERAND (exp, 0))
&& TREE_CODE (exp) == FUNCTION_DECL
/* For some reason, we sometimes wind up with multiple FUNCTION_DECL
- prototypes for objc_get_class(). Thankfuly, they seem to share the
+ prototypes for objc_get_class(). Thankfully, they seem to share the
same function type. */
&& TREE_TYPE (exp) == TREE_TYPE (objc_get_class_decl)
&& !strcmp (IDENTIFIER_POINTER (DECL_NAME (exp)), TAG_GETCLASS)
@@ -9015,7 +9015,7 @@ handle_impent (struct imp_entry *impent)
}
}
-/* The Fix-and-Countinue functionality available in Mac OS X 10.3 and
+/* The Fix-and-Continue functionality available in Mac OS X 10.3 and
later requires that ObjC translation units participating in F&C be
specially marked. The following routine accomplishes this. */
diff --git a/gcc/tree.def b/gcc/tree.def
index d56142f4e81..afdeadcd154 100644
--- a/gcc/tree.def
+++ b/gcc/tree.def
@@ -553,7 +553,7 @@ DEFTREECODE (CLEANUP_POINT_EXPR, "cleanup_point_expr", 'e', 1)
fact that the expression for the array contains the dereference of
the fat pointer that obtained the array pointer. */
-/* Denotes a record to later be substitued before evaluating this expression.
+/* Denotes a record to later be substituted before evaluating this expression.
The type of this expression is used to find the record to replace it. */
DEFTREECODE (PLACEHOLDER_EXPR, "placeholder_expr", 'x', 0)
diff --git a/gcc/config/arm/arm.c b/gcc/config/arm/arm.c
index 206647b1cb6..1c42ad0046c 100644
--- a/gcc/config/arm/arm.c
+++ b/gcc/config/arm/arm.c
@@ -2288,7 +2288,7 @@ arm_function_arg (CUMULATIVE_ARGS *pcum, enum machine_mode mode,
/* Compute operand 2 of the call insn. */
return GEN_INT (pcum->call_cookie);
/* Only allow splitting an arg between regs and memory if all preceeding
args were allocated to regs. For args passed by reference we only count
the reference pointer. */
if (pcum->can_split)
@@ -9909,8 +9909,8 @@ arm_get_frame_offsets (void)
if (reload_completed)
return offsets;
- /* Initialy this is the size of the local variables. It will translated
- into an offset once we have determined the size of preceeding data. */
+ /* Initially this is the size of the local variables. It will translated
+ into an offset once we have determined the size of preceding data. */
frame_size = ROUND_UP_WORD (get_frame_size ());
leaf = leaf_function_p ();
@@ -10013,7 +10013,7 @@ arm_get_frame_offsets (void)
}
-/* Calculate the realative offsets for the different stack pointers. Positive
+/* Calculate the relative offsets for the different stack pointers. Positive
offsets are in the direction of stack growth. */
unsigned int
@@ -2288,7 +2288,7 @@ arm_function_arg (CUMULATIVE_ARGS *pcum, enum machine_mode mode,
/* Compute operand 2 of the call insn. */
return GEN_INT (pcum->call_cookie);
- /* Only allow splitting an arg between regs and memory if all preceeding
+ /* Only allow splitting an arg between regs and memory if all preceding
args were allocated to regs. For args passed by reference we only count
the reference pointer. */